@@ -1,10 +1,10 @@
-from ...abstract_webtools import *
+
 from ..userAgentManager import *
 from ..cipherManager import *
 from ..sslManager import *
 from ..tlsAdapter import *
 from ..networkManager import *
-from ..seleniumManager import *
+from ..seleneumManager import *
 from ..urlManager import *
 logging.basicConfig(level=logging.INFO)
 
@@ -59,11 +59,13 @@ class requestManager:
         - The SafeRequest class is designed for making HTTP requests with error handling and retries.
         - It provides methods for authentication, response handling, and error management.
     """
-    def __init__(self,url=None,
+class requestManager:
+    def __init__(self,
+                 url=None,
                  source_code=None,
                  url_mgr=None,
                  network_manager=None,
-                 user_agent_manager=None,
+                 ua_mgr=None,
                  ssl_manager=None,
                  ssl_options=None,
                  tls_adapter=None,
@@ -94,40 +96,56 @@ class requestManager:
         self.url = get_url(url=url, url_mgr=self.url_mgr)
         self._url_mgr = self.url_mgr
         self._url = self.url
-        self.user_agent = user_agent
-        self.user_agent_manager = user_agent_manager or UserAgentManager(user_agent=self.user_agent)
-        self.headers = headers or self.user_agent_manager.header or {'Accept': '*/*'}
-        self.user_agent = self.user_agent_manager.user_agent
+
+        # User-Agent manager
+        self.ua_mgr = ua_mgr or get_ua_mgr(user_agent=user_agent)
+        self.user_agent = self.ua_mgr.user_agent
+        self.headers = headers or self.ua_mgr.generate_headers(url=self.url)  # fixed
+
+        # TLS / SSL / Network
         self.ciphers = ciphers or CipherManager().ciphers_string
         self.certification = certification
-        self.ssl_options = ssl_options
-        self.ssl_manager = ssl_manager or SSLManager(ciphers=self.ciphers, ssl_options=self.ssl_options, certification=self.certification)
-        self.tls_adapter = tls_adapter or TLSAdapter(ssl_manager=self.ssl_manager, certification=self.certification, ssl_options=self.ssl_manager.ssl_options)
-        self.network_manager = network_manager or NetworkManager(user_agent_manager=self.user_agent_manager, ssl_manager=self.ssl_manager, tls_adapter=self.tls_adapter, user_agent=user_agent, proxies=proxies, cookies=cookies, ciphers=ciphers, certification=certification, ssl_options=ssl_options)
-        self.stream = stream
-        self.tls_adapter = self.network_manager.tls_adapter
-        self.ciphers = self.network_manager.ciphers
-        self.certification = self.network_manager.certification
-        self.ssl_options = self.network_manager.ssl_options
-        self.proxies = self.network_manager.proxies
-        self.timeout = timeout
-        self.cookies = self.network_manager.cookies
+        self.ssl_manager = ssl_manager or SSLManager(ciphers=self.ciphers)
+        self.tls_adapter = tls_adapter or TLSAdapter(
+            ssl_manager=self.ssl_manager,
+            certification=self.certification
+        )
+        self.network_manager = network_manager or NetworkManager(
+            user_agent_manager=self.ua_mgr,
+            ssl_manager=self.ssl_manager,
+            tls_adapter=self.tls_adapter,
+            user_agent=user_agent,
+            proxies=proxies,
+            cookies=cookies,
+            ciphers=ciphers,
+            certification=certification,
+            ssl_options=ssl_options
+        )
+
+        # Session and defaults
         self.session = session or requests.Session()
+        self.proxies = self.network_manager.proxies
+        self.cookies = self.network_manager.cookies
+        self.protocol = protocol or 'https://'
+        self.timeout = timeout
         self.auth = auth
         self.spec_login = spec_login
-        self.password = password
         self.email = email
+        self.password = password
         self.checkbox = checkbox
         self.dropdown = dropdown
         self.login_url = login_url
         self.login_user_agent = login_user_agent
         self.login_referer = login_referer
-        self.protocol = protocol or 'https://'
-        self.stream = stream if isinstance(stream, bool) else False
+        self.stream = bool(stream)
+
         self.initialize_session()
+
         self.last_request_time = last_request_time
         self.max_retries = max_retries or 3
         self.request_wait_limit = request_wait_limit or 1.5
+
+        # Response placeholders
         self._response = None
         self.status_code = None
         self.source_code = None
@@ -137,12 +155,14 @@ class requestManager:
         self.extracted_urls = []
         self.php_blocks = []
         self._response_data = None
+
         if source_code is not None:
             self._response = source_code
             self.process_response_data()
         else:
             self.re_initialize()
 
+
     def update_url_mgr(self, url_mgr):
         self.url_mgr = url_mgr
         self.re_initialize()
